<?php
	interface nodo {
		function predice($instancia);
	}
	
	class nodo_terminal implements nodo {
		public $valor;
		
		function __construct($valor)
		{
			$this->valor = $valor;
		}
		
		function predice($instancia)
		{
			return $this->valor;
		}
	}
	
	class nodo_no_terminal implements nodo {
		public $variable;
		public $ramas;
		
		function __construct($variable, $ramas)
		{
			$this->variable = $variable;
			$this->ramas = $ramas;
		}
		
		function predice($instancia)
		{
			$valor = $instancia[$this->variable];
			
			if (isset($this->ramas[$valor])) {
				return $this->ramas[$valor]->predice($instancia);
			}
		}
	}

	function calcula_bias($instancias, $variable)
	{
		$cuentas = array_count_values(array_column($instancias, $variable));
		$max = max($cuentas);
		
		return [ 
			'valor' => array_search($max, $cuentas),
			'porcentaje' => $max / count($instancias)
		];
	}
	
	function ramifica($instancias, $variable)
	{
		$ramas = [ ];
		
		foreach ($instancias as $instancia) {
			$ramas[$instancia[$variable]][] = $instancia;
		}
		
		return $ramas;
	}
	
	function construye_arbol($instancias, $variables)
	{
		$bias = calcula_bias($instancias, 'clase');
		
		if (empty($variables) || $bias['porcentaje'] > 0.85) {
			return new nodo_terminal($bias['valor']);
		}
		
		//...
	}
	
	// script principal

	$filas = file('_jugar.csv', FILE_IGNORE_NEW_LINES|FILE_SKIP_EMPTY_LINES);
	$variables = str_getcsv($filas[0]);
	$instancias = [ ];
	
	for ($i = 1; $i < count($filas); ++$i) {
		$instancias[] = array_combine($variables, str_getcsv($filas[$i]));
	}
?>